==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Dosya Ekle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Yukarı</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Liste görünümü</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Detaylı görünüm</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Eklenince diyaloğu kapat</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Dosya adı:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Dosya tipi:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="121"/>
        <location filename="../qmmpfiledialog.cpp" line="130"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp Dosya Diyaloğu</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="129"/>
        <source>About Qmmp File Dialog</source>
        <translation>Qmmp Dosya Diyaloğu Hakkında</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="131"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="134"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Bazı kodlar Qt kitaplığından kopyalanmıştır</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="272"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="288"/>
        <source>Directories</source>
        <translation>Dizinler</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
        <source>already exists.</source>
        <translation>zaten mevcut.</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
        <source>Do you want to replace it?</source>
        <translation>Yerini değiştirmek istiyor musunuz?</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Dosya Ekle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Yukarı</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Liste görünümü</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Detaylı görünüm</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Eklenince diyaloğu kapat</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Dosya adı:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Dosya tipi:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="121"/>
        <location filename="../qmmpfiledialog.cpp" line="130"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp Dosya Diyaloğu</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="129"/>
        <source>About Qmmp File Dialog</source>
        <translation>Qmmp Dosya Diyaloğu Hakkında</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="131"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="134"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Bazı kodlar Qt kitaplığından kopyalanmıştır</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="246"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="273"/>
        <source>Directories</source>
        <translation>Dizinler</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="442"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
